Knowledge Repo |release| documentation
######################################

.. toctree::
  :hidden:

  installation
  quickstart
  deployment
  workflows/overview
  under_the_hood/overview
  contributing

The Knowledge Repo is a set of tools that manage a curated collection of
"Knowledge Posts" along with a web interface to view and disseminate them.
Knowledge Posts are representations of technical and non-technical documents
that include document metadata, original source files, and a rendered Markdown
file generated from them. The Knowledge Repo includes tooling to create
Knowledge Posts from a variety of commonly used formats, such as Jupyter and R
Markdown notebooks.

It was created at Airbnb to solve the problem of scaling technical knowledge
dissemination within a growing team of data scientists, as sharing progress via
one-off emails, documents, slideshows and git repositories was becoming
increasingly impractical. It has since grown to be an indispensable method by
which knowledge is shared not just between data scientists, but also with the
rest of the company. We invite you to join us in deploying and using the
Knowledge Repository in your workplace.

For more information about the motivation and inspiration behind this project,
we encourage you to read our `Medium Post`_.

.. _`Medium Post`: https://medium.com/airbnb-engineering/scaling-knowledge-at-airbnb-875d73eff091


Feedback
--------

The Knowledge Repo is a reasonably complete internal publishing service, and we
hope that you find it useful. If you have difficulties deploying the Knowledge
Repo in your organisation, we would love to hear from you; particularly as it
pertains to the following:

 - How easy is it to set up the git knowledge post repository?
 - How easy is it to set up the web application, and make it live internally
   within your organization?
 - Where are the gaps in our documentation that we should fill in to assist
   others in understanding the system?
 - At a higher level, are there any blockers or barriers to setting up the
   Knowledge Repo in your organization?

.. only:: html

  Indices and tables
  ==================

  * :ref:`genindex`
  * :ref:`modindex`
  * :ref:`search`
